@@ -403,8 +403,8 @@ class MatlabTranslator(Translator):
         return '% {}'.format(cmt_str).strip()
 
     @classmethod
-    def codify(cls, parameters):
-        content = '{}\n'.format(cls.comment('Parameters'))
+    def codify(cls, parameters, comment='Parameters'):
+        content = '{}\n'.format(cls.comment(comment))
         for name, val in parameters.items():
             content += '{};\n'.format(cls.assign(name, cls.translate(val)))
         return content
@@ -548,6 +548,9 @@ papermill_translators.register("matlab", MatlabTranslator)
 papermill_translators.register(".net-csharp", CSharpTranslator)
 papermill_translators.register(".net-fsharp", FSharpTranslator)
 papermill_translators.register(".net-powershell", PowershellTranslator)
+papermill_translators.register("pysparkkernel", PythonTranslator)
+papermill_translators.register("sparkkernel", ScalaTranslator)
+papermill_translators.register("sparkrkernel", RTranslator)
 
 
 def translate_parameters(kernel_name, language, parameters, comment='Parameters'):
